@@ -25,7 +25,7 @@
 #include <KLocalizedString>
 #include <QLabel>
 #include <QHBoxLayout>
-#include <QDomNode>
+#include <QXmlStreamReader>
 #include "libksieve_debug.h"
 
 using namespace KSieveUi;
@@ -53,7 +53,8 @@ QString SieveActionKeep::code(QWidget *w) const
 
 QString SieveActionKeep::help() const
 {
-    return i18n("The \"keep\" action is whatever action is taken in lieu of all other actions, if no filtering happens at all; generally, this simply means to file the message into the user's main mailbox.");
+    return i18n(
+        "The \"keep\" action is whatever action is taken in lieu of all other actions, if no filtering happens at all; generally, this simply means to file the message into the user's main mailbox.");
 }
 
 QWidget *SieveActionKeep::createParamWidget(QWidget *parent) const
@@ -76,36 +77,35 @@ QWidget *SieveActionKeep::createParamWidget(QWidget *parent) const
     }
 }
 
-bool SieveActionKeep::setParamWidgetValue(const QDomElement &element, QWidget *w, QString &error)
+bool SieveActionKeep::setParamWidgetValue(QXmlStreamReader &element, QWidget *w, QString &error)
 {
     if (mHasFlagSupport) {
-        QDomNode node = element.firstChild();
-        while (!node.isNull()) {
-            QDomElement e = node.toElement();
-            if (!e.isNull()) {
-                const QString tagName = e.tagName();
-                if (tagName == QLatin1String("list")) {
-                    SelectFlagsWidget *flagsWidget = w->findChild<SelectFlagsWidget *>(QStringLiteral("flagswidget"));
-                    flagsWidget->setFlags(AutoCreateScriptUtil::listValue(e));
-                } else if (tagName == QLatin1String("str")) {
-                    SelectFlagsWidget *flagsWidget = w->findChild<SelectFlagsWidget *>(QStringLiteral("flagswidget"));
-                    flagsWidget->setFlags(QStringList() << e.text());
-                } else if (tagName == QLatin1String("tag") && e.text() == QLatin1String("flags")) {
-                    //nothing :)
-                } else if (tagName == QLatin1String("crlf")) {
-                    //nothing
-                } else if (tagName == QLatin1String("comment")) {
-                    //implement in the future ?
-                } else {
-                    unknownTag(tagName, error);
-                    qCDebug(LIBKSIEVE_LOG) << " SieveActionAbstractFlags::setParamWidgetValue unknown tag :" << tagName;
-                }
+        while (element.readNextStartElement()) {
+            const QStringRef tagName = element.name();
+            if (tagName == QLatin1String("list")) {
+                SelectFlagsWidget *flagsWidget = w->findChild<SelectFlagsWidget *>(QStringLiteral("flagswidget"));
+                flagsWidget->setFlags(AutoCreateScriptUtil::listValue(element));
+            } else if (tagName == QLatin1String("str")) {
+                SelectFlagsWidget *flagsWidget = w->findChild<SelectFlagsWidget *>(QStringLiteral("flagswidget"));
+                flagsWidget->setFlags(QStringList() << element.readElementText());
+            } else if (tagName == QLatin1String("tag") && element.readElementText() == QLatin1String("flags")) {
+                //nothing :)
+                //Don't skip here.
+            } else if (tagName == QLatin1String("crlf")) {
+                element.skipCurrentElement();
+                //nothing
+            } else if (tagName == QLatin1String("comment")) {
+                element.skipCurrentElement();
+                //implement in the future ?
+            } else {
+                unknownTag(tagName, error);
+                qCDebug(LIBKSIEVE_LOG) << " SieveActionAbstractFlags::setParamWidgetValue unknown tag :" << tagName;
             }
-            node = node.nextSibling();
         }
     } else {
         qCDebug(LIBKSIEVE_LOG) << " Server doesn't support imapflags";
     }
+
     return true;
 }
 
@@ -124,4 +124,3 @@ QUrl SieveActionKeep::href() const
 {
     return SieveEditorUtil::helpUrl(SieveEditorUtil::strToVariableName(name()));
 }
-
