@@ -20,22 +20,21 @@
 #define SIEVEACTIONNOTIFY_H
 
 #include "sieveaction.h"
-namespace KSieveUi
-{
+namespace KSieveUi {
 class SieveActionNotify : public SieveAction
 {
     Q_OBJECT
 public:
     explicit SieveActionNotify(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, QObject *parent = nullptr);
 
-    QWidget *createParamWidget(QWidget *parent) const Q_DECL_OVERRIDE;
-    QString code(QWidget *) const Q_DECL_OVERRIDE;
-    QString serverNeedsCapability() const Q_DECL_OVERRIDE;
-    bool needCheckIfServerHasCapability() const Q_DECL_OVERRIDE;
-    bool setParamWidgetValue(const QDomElement &element, QWidget *parent, QString &error) Q_DECL_OVERRIDE;
-    QString help() const Q_DECL_OVERRIDE;
-    QStringList needRequires(QWidget *) const Q_DECL_OVERRIDE;
-    QUrl href() const Q_DECL_OVERRIDE;
+    QWidget *createParamWidget(QWidget *parent) const override;
+    QString code(QWidget *) const override;
+    QString serverNeedsCapability() const override;
+    bool needCheckIfServerHasCapability() const override;
+    bool setParamWidgetValue(QXmlStreamReader &element, QWidget *parent, QString &error) override;
+    QString help() const override;
+    QStringList needRequires(QWidget *) const override;
+    QUrl href() const override;
 };
 }
 
