@@ -20,8 +20,7 @@
 #define SELECTVACATIONCOMBOBOX_H
 #include <KComboBox>
 
-namespace KSieveUi
-{
+namespace KSieveUi {
 class SelectVacationComboBox : public KComboBox
 {
     Q_OBJECT
