@@ -27,10 +27,10 @@
 using namespace KSieveUi;
 
 SieveCondition::SieveCondition(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, const QString &name, const QString &label, QObject *parent)
-    : QObject(parent),
-      mSieveGraphicalModeWidget(sieveGraphicalModeWidget),
-      mName(name),
-      mLabel(label)
+    : QObject(parent)
+    , mSieveGraphicalModeWidget(sieveGraphicalModeWidget)
+    , mName(name)
+    , mLabel(label)
 {
 }
 
@@ -93,14 +93,14 @@ QString SieveCondition::help() const
     return QString();
 }
 
-bool SieveCondition::setParamWidgetValue(const QDomElement &/*element*/, QWidget */*parent*/, bool /*notCondition*/, QString &/*error*/)
+bool SieveCondition::setParamWidgetValue(QXmlStreamReader & /*element*/, QWidget * /*parent*/, bool /*notCondition*/, QString & /*error*/)
 {
     return true;
 }
 
-void SieveCondition::unknownTag(const QString &tag, QString &error)
+void SieveCondition::unknownTag(const QStringRef &tag, QString &error)
 {
-    error += i18n("Unknown tag \"%1\" during parsing condition \"%2\"", tag, name()) + QLatin1Char('\n');
+    error += i18n("Unknown tag \"%1\" during parsing condition \"%2\"", *tag.string(), name()) + QLatin1Char('\n');
 }
 
 void SieveCondition::unknowTagValue(const QString &tagValue, QString &error)
@@ -110,7 +110,12 @@ void SieveCondition::unknowTagValue(const QString &tagValue, QString &error)
 
 void SieveCondition::tooManyArgument(const QString &tagName, int index, int maxValue, QString &error)
 {
-    error += i18n("Too many argument found for \"%1\", max value is %2, number of value found %3 for %4", name(), maxValue, index, tagName) + QLatin1Char('\n');
+    error += i18n("Too many argument found for \"%1\", max value is %2, number of value found %3 for %4", name(), maxValue, (index + 1), tagName) + QLatin1Char('\n');
+}
+
+void SieveCondition::tooManyArgument(const QStringRef &tagName, int index, int maxValue, QString &error)
+{
+    tooManyArgument(tagName.toString(), index, maxValue, error);
 }
 
 void SieveCondition::serverDoesNotSupportFeatures(const QString &feature, QString &error)
@@ -118,7 +123,22 @@ void SieveCondition::serverDoesNotSupportFeatures(const QString &feature, QStrin
     error += i18n("A feature \"%1\" in condition \"%2\" is not supported by server", feature, name()) + QLatin1Char('\n');
 }
 
-QUrl KSieveUi::SieveCondition::href() const
+QUrl SieveCondition::href() const
 {
     return QUrl();
 }
+
+QString SieveCondition::comment() const
+{
+    return mComment;
+}
+
+void SieveCondition::setComment(const QString &comment)
+{
+    mComment = comment;
+}
+
+QString SieveCondition::generateComment() const
+{
+    return {};
+}
