@@ -214,7 +214,6 @@ void SieveEditorTextModeWidget::slotShowGoToLine()
 
 void SieveEditorTextModeWidget::generateXml()
 {
-#if !defined(NDEBUG)
     const QByteArray script = mTextEdit->toPlainText().toUtf8();
     KSieve::Parser parser(script.begin(),
                           script.begin() + script.length());
@@ -229,7 +228,6 @@ void SieveEditorTextModeWidget::generateXml()
     }
     dlg->exec();
     delete dlg;
-#endif
 }
 
 void SieveEditorTextModeWidget::createRulesGraphically()
@@ -237,6 +235,7 @@ void SieveEditorTextModeWidget::createRulesGraphically()
     QPointer<AutoCreateScriptDialog> dlg = new AutoCreateScriptDialog(this);
     dlg->setSieveCapabilities(mSieveCapabilities);
     dlg->setSieveImapAccountSettings(mSieveImapAccountSettings);
+    dlg->setListOfIncludeFile(mListOfIncludeFile);
     if (dlg->exec()) {
         QString requires;
         const QString script = dlg->script(requires);
@@ -390,11 +389,12 @@ void SieveEditorTextModeWidget::printPreview()
     if (w == mEditorWidget) {
         bool restoreSpellCheck = mTextEdit->checkSpellingEnabled();
         mTextEdit->setCheckSpellingEnabled(false);
-        PimCommon::KPimPrintPreviewDialog previewdlg(this);
-        connect(&previewdlg, &QPrintPreviewDialog::paintRequested, this, [this](QPrinter *printer) {
+        QPointer<PimCommon::KPimPrintPreviewDialog> previewdlg = new PimCommon::KPimPrintPreviewDialog(this);
+        connect(previewdlg.data(), &QPrintPreviewDialog::paintRequested, this, [this](QPrinter *printer) {
             mTextEdit->print(printer);
         });
-        previewdlg.exec();
+        previewdlg->exec();
+        delete previewdlg;
         mTextEdit->setCheckSpellingEnabled(restoreSpellCheck);
     }
 }
@@ -478,6 +478,11 @@ void SieveEditorTextModeWidget::setDebugScript(const QString &debug)
     mDebugTextEdit->editor()->appendHtml(debug);
 }
 
+void SieveEditorTextModeWidget::setListOfIncludeFile(const QStringList &listOfIncludeFile)
+{
+    mListOfIncludeFile = listOfIncludeFile;
+}
+
 void SieveEditorTextModeWidget::setSieveCapabilities(const QStringList &capabilities)
 {
     mSieveCapabilities = capabilities;
