@@ -17,21 +17,19 @@
  */
 
 #include "findbarwebengineview.h"
-#include <PimCommon/LineEditWithCompleter>
+#include <PimCommon/LineEditWithCompleterNg>
 #include <QWebEngineView>
 #include <QAction>
-
 using namespace KSieveUi;
 
 class KSieveUi::FindBarWebEngineViewPrivate
 {
 public:
     FindBarWebEngineViewPrivate()
-        : mView(nullptr)
     {
     }
 
-    QWebEngineView *mView;
+    QWebEngineView *mView = nullptr;
 };
 
 FindBarWebEngineView::FindBarWebEngineView(QWebEngineView *view, QWidget *parent)
