@@ -60,17 +60,18 @@ public:
     {
     }
 
-    CustomManageSieveWidget *mTreeView;
-    SieveEditor *mSieveEditor;
+    CustomManageSieveWidget *mTreeView = nullptr;
+    SieveEditor *mSieveEditor = nullptr;
 
     QUrl mCurrentURL;
     QStringList mCurrentCapabilities;
+    QStringList mListOfIncludeFile;
     KSieveUi::SieveImapAccountSettings mSieveImapAccountSettings;
 
-    QPushButton *mNewScript;
-    QPushButton *mEditScript;
-    QPushButton *mDeleteScript;
-    QPushButton *mDeactivateScript;
+    QPushButton *mNewScript = nullptr;
+    QPushButton *mEditScript = nullptr;
+    QPushButton *mDeleteScript = nullptr;
+    QPushButton *mDeactivateScript = nullptr;
 
     bool mIsNewScript : 1;
     bool mWasActive : 1;
@@ -164,21 +165,23 @@ void ManageSieveScriptsDialog::slotUpdateButtons(QTreeWidgetItem *item)
     d->mDeactivateScript->setEnabled(desactivateScriptAction);
 }
 
-void ManageSieveScriptsDialog::slotEditScript(const QUrl &url, const QStringList &capabilities, const KSieveUi::SieveImapAccountSettings &sieveImapAccountSettings)
+void ManageSieveScriptsDialog::slotEditScript(const ManageSieveWidget::ScriptInfo &info)
 {
-    d->mCurrentURL = url;
-    d->mCurrentCapabilities = capabilities;
+    d->mCurrentURL = info.currentUrl;
+    d->mCurrentCapabilities = info.currentCapabilities;
+    d->mListOfIncludeFile = info.scriptList;
     d->mIsNewScript = false;
-    d->mSieveImapAccountSettings = sieveImapAccountSettings;
-    KManageSieve::SieveJob *job = KManageSieve::SieveJob::get(url);
+    d->mSieveImapAccountSettings = info.sieveImapAccountSettings;
+    KManageSieve::SieveJob *job = KManageSieve::SieveJob::get(info.currentUrl);
     connect(job, &KManageSieve::SieveJob::result, this, &ManageSieveScriptsDialog::slotGetResult);
 }
 
-void ManageSieveScriptsDialog::slotNewScript(const QUrl &url, const QStringList &capabilities, const SieveImapAccountSettings &sieveImapAccountSettings)
+void ManageSieveScriptsDialog::slotNewScript(const ManageSieveWidget::ScriptInfo &info)
 {
-    d->mCurrentCapabilities = capabilities;
-    d->mSieveImapAccountSettings = sieveImapAccountSettings;
-    d->mCurrentURL = url;
+    d->mCurrentCapabilities = info.currentCapabilities;
+    d->mSieveImapAccountSettings = info.sieveImapAccountSettings;
+    d->mCurrentURL = info.currentUrl;
+    d->mListOfIncludeFile = info.scriptList;
     d->mIsNewScript = true;
     slotGetResult(nullptr, true, QString(), false);
 }
@@ -197,16 +200,18 @@ void ManageSieveScriptsDialog::slotGetResult(KManageSieve::SieveJob *job, bool s
 
     disableManagerScriptsDialog(true);
     d->mSieveEditor = new SieveEditor;
+    d->mSieveEditor->show();
     d->mSieveEditor->setScriptName(d->mCurrentURL.fileName());
     d->mSieveEditor->setSieveCapabilities(d->mCurrentCapabilities);
     d->mSieveEditor->setScript(script, true); /*clear undo/redo*/
     d->mSieveEditor->setSieveImapAccountSettings(d->mSieveImapAccountSettings);
+    d->mSieveEditor->setListOfIncludeFile(d->mListOfIncludeFile);
 
     connect(d->mSieveEditor, &SieveEditor::okClicked, this, &ManageSieveScriptsDialog::slotSieveEditorOkClicked);
     connect(d->mSieveEditor, &SieveEditor::cancelClicked, this, &ManageSieveScriptsDialog::slotSieveEditorCancelClicked);
     connect(d->mSieveEditor, &SieveEditor::checkSyntax, this, &ManageSieveScriptsDialog::slotSieveEditorCheckSyntaxClicked);
-    d->mSieveEditor->show();
     d->mWasActive = isActive;
+    d->mSieveEditor->setModified(false);
 }
 
 void ManageSieveScriptsDialog::slotSieveEditorCheckSyntaxClicked()
